#! /usr/bin/env python
"""
fix sip includes
usage: %s [-vb] files.sip
       -v verbose mode (cumulative)
       -b create backup (file.sip.bak)
"""
# (c)reated by Hans-Peter Jansen, LISA GmbH, Berlin
#
# Licence:      GPL http://www.gnu.org/licenses/gpl.html
#
# 2003-04-24    hp  initial version

import sys
import os
import getopt

verbose=0
backup=0
argv0=os.path.basename(sys.argv[0])

matchpat='unix:LIBS += -L@BL_SIPMODDIR@'
replacepat='unix:LIBS += -L@BL_BUILDDIR@ -L@BL_SIPMODDIR@'

def out(arg):
    err(arg, sys.stdout)

def vout(lvl, arg):
    if lvl > verbose:
        return
    err(arg)

def err(arg, ch = sys.stderr):
    if arg:
        ch.write(arg)
        if arg[-1] != "\n":
            ch.write("\n")
    else:
        ch.write("\n")
    ch.flush()

def usage(ret=0, arg=None):
    if arg:
        err("%s: %s" % (argv0, arg))
    err(__doc__ % (argv0))
    sys.exit(ret)

def strcmp(str, substr):
    l = len(substr)
    return len(str) >= l and str[:l] == substr

def filterFiles(files):
    for file in files:
        vout(2, "check: %s" % file)
        try:
            f = open(file, 'r')
        except:
            err("open file: %s %s" % (sys.exc_type, sys.exc_value))
            continue

        repf = "%s.$new$" % file
        try:
            rf = open(repf, 'w')
        except:
            err("open replace file: %s %s" % (sys.exc_type, sys.exc_value))
            continue

        match = 0
        while 1:
            line = f.readline()
            if not line:
                break
            # won't work if line is not properly terminated
            if strcmp(line, matchpat):
                vout(1, "match: %s" % file)
                match = 1
                line = replacepat + line[len(matchpat):]
            rf.write(line)

        f.close()
        rf.close()
        try:
            if match:
                if backup:
                    vout(2, "rename: %s -> %s" % (file, "%s.bak" % file))
                    os.rename(file, "%s.bak" % (file))
                vout(2, "rename: %s -> %s" % (repf, file))
                os.rename(repf, file)
            else:
                vout(2, "remove: %s" % (repf))
                os.remove(repf)
        except:
            err("replace old file: %s %s" % (sys.exc_type, sys.exc_value))
            continue

if __name__ == '__main__':
    try:
        optlist, args = getopt.getopt(sys.argv[1:], "vb")
    except getopt.error, msg:
        usage(1, msg)

    for opt, par in optlist:
        if opt == '-v':
            verbose += 1
        elif opt == '-b':
            backup = 1

    if not args:
        usage(1, "no files specified")

    sys.exit(filterFiles(args))

# vim:set et ts=4 sw=4:
